==> haskell-newtype-generics-0.5.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-1YrMUsRjRji2xgJjn7bE0C
key: newtype-generics-0.5.3-1YrMUsRjRji2xgJjn7bE0C
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 324806a1a73cea1efc16e252b1922459
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.4/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-1YrMUsRjRji2xgJjn7bE0C
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.5.3-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-8d9kmyzStaR9YUrCxCnvD2
key: newtype-generics-0.5.3-8d9kmyzStaR9YUrCxCnvD2
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 957e7cec718111eb54be04da1b6bafdd
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.6.4/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-8d9kmyzStaR9YUrCxCnvD2
depends:
    base-4.12.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
